@@ -1,24 +1,14 @@
 # This file is part of Gajim.
 #
-# Gajim is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published
-# by the Free Software Foundation; version 3 only.
-#
-# Gajim is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Gajim. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0-only
 
 from __future__ import annotations
 
-from typing import Any
 from typing import NamedTuple
-from typing import Optional
-from typing import Union
 
+from dataclasses import dataclass
+from datetime import datetime
+from datetime import timezone
 from enum import Enum
 from enum import IntEnum
 from enum import unique
@@ -38,8 +28,16 @@ PROPAGATE_EVENT = False
 MAX_MESSAGE_CORRECTION_DELAY = 300
 
 
-class EncryptionData(NamedTuple):
-    additional_data: Any = None
+class EncryptionInfoMsg(Enum):
+    BAD_OMEMO_CONFIG = _('This chat’s configuration is unsuitable for '
+                         'encryption with OMEMO. To use OMEMO in this chat, '
+                         'it should be non-anonymous and members-only.')
+    NO_FINGERPRINTS = _('To send an encrypted message, you have to decide '
+                        'whether to trust the device of your contact.')
+    QUERY_DEVICES = _('No devices found to encrypt this message to. '
+                      'Querying for devices now…')
+    UNDECIDED_FINGERPRINTS = _('There are devices for which you have not made '
+                               'a trust decision yet.')
 
 
 class Entity(NamedTuple):
@@ -63,7 +61,8 @@ class AvatarSize(IntEnum):
     WORKSPACE = 40
     WORKSPACE_EDIT = 100
     CHAT = 48
-    NOTIFICATION = 48
+    MESSAGE_REPLY = 24
+    NOTIFICATION = 96
     CALL = 100
     CALL_BIG = 200
     GROUP_INFO = 100
@@ -73,9 +72,9 @@ class AvatarSize(IntEnum):
     PUBLISH = 200
 
 
-class ArchiveState(IntEnum):
-    NEVER = 0
-    ALL = 1
+class ArchiveState:
+    NEVER = None
+    ALL = datetime(1970, 1, 1, tzinfo=timezone.utc)
 
 
 @unique
@@ -92,58 +91,6 @@ class PathType(IntEnum):
     FOLDER_OPTIONAL = 2
 
 
-@unique
-class KindConstant(IntEnum):
-    STATUS = 0
-    GCSTATUS = 1
-    GC_MSG = 2
-    SINGLE_MSG_RECV = 3
-    CHAT_MSG_RECV = 4
-    SINGLE_MSG_SENT = 5
-    CHAT_MSG_SENT = 6
-    ERROR = 7
-    FILE_TRANSFER_INCOMING = 8
-    FILE_TRANSFER_OUTGOING = 9
-    CALL_INCOMING = 10
-    CALL_OUTGOING = 11
-
-    def __str__(self):
-        return str(self.value)
-
-
-@unique
-class TypeConstant(IntEnum):
-    AIM = 0
-    GG = 1
-    HTTP_WS = 2
-    ICQ = 3
-    MSN = 4
-    QQ = 5
-    SMS = 6
-    SMTP = 7
-    TLEN = 8
-    YAHOO = 9
-    NEWMAIL = 10
-    RSS = 11
-    WEATHER = 12
-    MRIM = 13
-    NO_TRANSPORT = 14
-
-
-@unique
-class SubscriptionConstant(IntEnum):
-    NONE = 0
-    TO = 1
-    FROM = 2
-    BOTH = 3
-
-
-@unique
-class JIDConstant(IntEnum):
-    NORMAL_TYPE = 0
-    ROOM_TYPE = 1
-
-
 @unique
 class StyleAttr(Enum):
     COLOR = 'color'
@@ -232,7 +179,7 @@ class XmppUriQuery(Enum):
     JOIN = 'join'
 
     @staticmethod
-    def from_str(s: str) -> Optional[XmppUriQuery]:
+    def from_str(s: str) -> XmppUriQuery | None:
         try:
             return XmppUriQuery(s)
         except ValueError:
@@ -359,6 +306,12 @@ class CallType(Enum):
     VIDEO = 'video'
 
 
+@dataclass
+class Draft:
+    text: str
+    reply_pk: int | None
+
+
 MUC_CREATION_EXAMPLES = [
     (p_('Group chat name', 'Team'),
      p_('Group chat description', 'Project discussion'),
@@ -912,7 +865,11 @@ COMMON_FEATURES = [
     Namespace.JINGLE_BYTESTREAM,
     Namespace.JINGLE_IBB,
     Namespace.AVATAR_METADATA + '+notify',
-    Namespace.MESSAGE_MODERATE
+    Namespace.MESSAGE_MODERATE,
+    Namespace.REPLY,
+    Namespace.OMEMO_TEMP_DL + '+notify',
+    Namespace.STYLING,
+    Namespace.REACTIONS,
 ]
 
 
@@ -947,10 +904,16 @@ SHOW_STRING_MNEMONIC = {
 }
 
 GAJIM_FAQ_URI = 'https://dev.gajim.org/gajim/gajim/wikis/help/gajimfaq'
+GAJIM_PRIVACY_POLICY_URI = 'https://gajim.org/privacy/'
 GAJIM_WIKI_URI = 'https://dev.gajim.org/gajim/gajim/wikis'
 GAJIM_SUPPORT_JID = 'gajim@conference.gajim.org'
 
 
+# Clickable URI schemes not (yet) registered with IANA (see ./iana.py)
+NONREGISTERED_URI_SCHEMES = {
+    'gemini',
+}
+
 # This is an excerpt of Media Types from
 # https://www.iana.org/assignments/media-types/media-types.xhtml
 # plus some additions
@@ -1003,14 +966,22 @@ MIME_TYPES = (
     'audio/aac',
     'audio/ac3',
     'audio/flac',
+    'audio/mp3',
     'audio/mp4',
     'audio/mpeg',
     'audio/ogg',
     'audio/opus',
+    'audio/vnd.wave',
     'audio/wav',
+    'audio/wave',
+    'audio/x-aac',
     'audio/x-flac',
     'audio/x-m4a',
     'audio/x-matroska',
+    'audio/x-mp3',
+    'audio/x-mpeg',
+    'audio/x-ogg',
+    'audio/x-wav',
     # font/*
     'font/ttf',
     'font/woff',
@@ -1100,7 +1071,7 @@ class PresenceShowExt(Enum):
     def is_offline(self):
         return self == PresenceShowExt.OFFLINE
 
-    def __lt__(self, other: Union[PresenceShowExt, PresenceShow]) -> bool:
+    def __lt__(self, other: PresenceShowExt | PresenceShow) -> bool:
         if isinstance(other, PresenceShowExt):
             return False
         if not isinstance(other, PresenceShow):  # pyright: ignore
